import OSS from 'ali-oss';
import request from './request';

// 通过 OSS STS 模式上传
// oss client 是单例的
let ossClient
let stsInfo

function getOssClient() {
  // 请求 sts 临时授权
  return request('/oss-sts')
    .then((sts) => {
      stsInfo = sts
      ossClient = new OSS({
        accessKeyId: sts.accessKeyId,
        accessKeySecret: sts.accessKeySecret,
        stsToken: sts.stsToken,
        bucket: sts.bucket,
        endpoint: sts.endpoint,
        refreshSTSToken: () => {
          return request('/oss-sts').then((res) => {
            return {
              accessKeyId: res.accessKeyId,
              accessKeySecret: res.accessKeySecret,
              stsToken: res.stsToken,
            }
          })
        }
      });
    })
    .catch((e) => {
      return Promise.resolve(e);
    });
}

// https://github.com/react-component/upload#customrequest
export default ({ file, onSuccess, onError }) => {

  const upload = () => {
    const data = new FormData();
    data.append('file', file);
    const now = new Date();
    const fileName = `${stsInfo.path}/${now.valueOf()}-${file.name}`;

    ossClient
      .put(fileName, file)
      .then((res) => {
        onSuccess(res.url, file);
      })
      .catch((e2) => {
        onError(e2);
      });
  }

  if (!ossClient) {
    getOssClient().then(() => {
      upload()
    })
    .catch((e) => {
      onError(e);
    });
  } else {
    upload()
  }

  return {
    abort: () => {},
  };
};
